<?php
namespace JsonStreamingParser\Listener;

use JsonStreamingParser\Listener;

/**
 * This basic CasesJSON implementation of a listener simply constructs an in-memory
 * representation of the JSON document at the second level,  a single case will be kept in memory
*  rather than the whole case array for chunking. The call back function can then stash the cases
*  until a chunk is accumulated and then process for inserts
 */
class SyncCasesJsonListener implements Listener
{
    protected $questionnaire;
	protected $topLevelKeyValues;
	
    protected $stack;
    protected $key;

    // Level is required so we know how nested we are.
    protected $level;

    /**
     * @var Callable
     */
    protected $callback;

    /**
     *
     * @param Callable $callback
     */
    public function __construct($callback = null)
    {
        $this->callback = $callback;
    }

    public function getQuestionnaire()
    {
        return $this->questionnaire;
    }

    public function startDocument()
    {
        $this->stack = [];
        $this->level = 0;
        // Key is an array so that we can can remember keys per level to avoid
        // it being reset when processing child keys.
        $this->key = [];
    }

    public function endDocument()
    {
        // w00t!
    }

    public function startObject()
    {
		if ($this->level == 1 && empty($this->topLevelKeyValues)) {//if about to start second level objects processing store the topLevelKeys before reset.
			$obj = array_pop($this->stack);
			$this->topLevelKeyValues = $obj;
			$this->stack = $obj; 
		}
        $this->level++;
        $this->stack[] = [];
        // Reset the stack when entering the second level
        if ($this->level == 2) {
            $this->stack = [];
            $this->key[$this->level] = null;
        }
    }

    public function endObject()
    {
        $this->level--;
        $obj = array_pop($this->stack);
        if (empty($this->stack)) {
            // doc is DONE!
            $this->questionnaire = $obj;
        } else {
            $this->value($obj);
        }
        // Call the callback when returning to the second level
        if ($this->level == 2 && is_callable($this->callback)) {
            call_user_func($this->callback, $this->questionnaire, $this->topLevelKeyValues);
        }
    }

    public function startArray()
    {
        $this->startObject();
    }

    public function endArray()
    {
        $this->endObject();
    }

    /**
     * @param string $key
     */
    public function key($key)
    {
        $this->key[$this->level] = $key;
    }

    /**
     * Value may be a string, integer, boolean, null
     * @param mixed $value
     */
    public function value($value)
    {
        $obj = array_pop($this->stack);
        if (!empty($this->key[$this->level])) {
            $obj[$this->key[$this->level]] = $value;
            $this->key[$this->level] = null;
        } else {
            $obj[] = $value;
        }
        $this->stack[] = $obj;
    }

    public function whitespace($whitespace)
    {
        // do nothing
    }
}
